package com.huiju.estateagents.controller;


import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.JWTUtils;
import com.huiju.estateagents.service.ITaRecommendCustomerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import com.huiju.estateagents.base.BaseController;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
 * 推荐客户表 前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-05-10
 */
@RestController
@RequestMapping("/api")
public class TaRecommendCustomerController extends BaseController {

    @Autowired
    ITaRecommendCustomerService taRecommendCustomerService;

    /**
     * 我的客户列表
     * @param pageNumber
     * @param pageSize
     * @param keywords
     * @param request
     * @return
     */
    @GetMapping("/wx/customer/list")
    public ResponseBean getMyCustList(@RequestParam int pageNumber, @RequestParam int pageSize, String keywords, HttpServletRequest request) {
        if (pageNumber < 0 || pageSize < 0) {
            return ResponseBean.error("分页参数不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        String openid = JWTUtils.getSubject(request);
        return taRecommendCustomerService.getMyCustList(openid, keywords, pageNumber, pageSize);
    }

    /**
     * 客户详情
     * @param id
     * @return
     */
    @GetMapping("/wx/customer/{id}")
    public ResponseBean getCustDetail(@PathVariable String id) {
        if (null == id || "".equals(id.trim())) {
            return ResponseBean.error("请求地址错误", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        return taRecommendCustomerService.getCustDetail(id);
    }

    /**
     * 客户编辑
     * @param paramStr
     * @return
     */
    @PostMapping("/wx/customer/edit")
    public ResponseBean updateCust(@RequestBody String paramStr) {
        return taRecommendCustomerService.updateCustByJSON(paramStr);
    }

    /**
     * 推荐客户
     * @param paramStr
     * @param request
     * @return
     */
    @PostMapping("/wx/customer/new")
    public ResponseBean recommendCust(@RequestBody String paramStr, HttpServletRequest request) {
        String openid = JWTUtils.getSubject(request);
        return taRecommendCustomerService.recommendCust(paramStr, openid);
    }
}
